referrerpolicy=no-referrer-when-downgrade

chill_inactive

Function chill_inactive 

pub fn chill_inactive<T: Config>(
    stash: T::AccountId,
    proof: BoundedVec<EraIndex, T::HistoryDepth>,
)
Chill an inactive validator.

This extrinsic can be called by anyone, given that the valid inactivity proof is provided. Inactivity proof is a vector of eras where the given validator was inactive.

Requirements for the inactivity proof:

  • The length must be equal to ChillInactiveThreshold.
  • It must be sorted in ascending order.
  • It must not contain duplicate entries.
  • For every era the stash account must be exposed.
  • Every item must pass the check provided by Config::IsValidatorInactive.
  • Every era must be less than the active era.

On a successfull execution, caller doesn’t pay fees.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::chill_inactive.