referrerpolicy=no-referrer-when-downgrade

set_validator_self_stake_incentive_config

Function set_validator_self_stake_incentive_config 

pub fn set_validator_self_stake_incentive_config<T: Config>(
    optimum_self_stake: ConfigOp<BalanceOf<T>>,
    hard_cap_self_stake: ConfigOp<BalanceOf<T>>,
    self_stake_slope_factor: ConfigOp<Perbill>,
)
Configure the validator self-stake incentive parameters.

The dispatch origin must be T::AdminOrigin.

Changes take effect in the next era when rewards are calculated.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_validator_self_stake_incentive_config.